// $Id: resource.h,v 1.33 2005/03/14 11:57:17 yuya Exp $

#define RT_EXERB                        100
#define ID_EXERB                        100
#define IDD_EXCEPTION                   101
#define IDI_RUBY                        102

#define ID_CLOSE                        1000
#define IDC_EDIT_MESSAGE                1001
#define IDC_EDIT_BACKTRACE              1002
#define IDC_EDIT_TYPE                   1003

#ifndef IDC_STATIC
#define IDC_STATIC -1
#endif

#define EXERB_RES_EXERB_VERSION1 3,3,0,0
#define EXERB_RES_EXERB_VERSION2 "3.3.0"
